gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r28748 - msh/src


From: gnunet
Subject: [GNUnet-SVN] r28748 - msh/src
Date: Wed, 21 Aug 2013 17:12:08 +0200

Author: harsha
Date: 2013-08-21 17:12:08 +0200 (Wed, 21 Aug 2013)
New Revision: 28748

Modified:
   msh/src/msh.c
Log:
- return successfully if we ever get to exec on remote host


Modified: msh/src/msh.c
===================================================================
--- msh/src/msh.c       2013-08-21 14:49:23 UTC (rev 28747)
+++ msh/src/msh.c       2013-08-21 15:12:08 UTC (rev 28748)
@@ -466,8 +466,10 @@
   GNUNET_assert (NULL != fh_stdin);
   GNUNET_assert (NULL != fh_stdout);
   state = STATE_FORWARD_STREAMS;
+  task_fwd_stdin = 
       GNUNET_SCHEDULER_add_read_file (GNUNET_TIME_UNIT_FOREVER_REL,
                                       fh_stdin, &fwd_stdin, NULL);
+  result = GNUNET_OK;
   return GNUNET_OK;
 }
 
@@ -641,18 +643,18 @@
  * Function called with the result on the service test.
  *
  * @param cls NULL
  * @param result GNUNET_YES if the service is running,
  *               GNUNET_NO if the service is not running
  *               GNUNET_SYSERR if the configuration is invalid
  */
 static void
-result_cb (void *cls, int result)
+status_cb (void *cls, int status)
 {
   struct MSH_MSG_AddressLookup *msg;
   uint16_t size;
 
   test = NULL;
-  if (GNUNET_YES != result)
+  if (GNUNET_YES != status)
   {
     LOG_ERROR ("Service not running\n");
     return;
@@ -727,7 +729,7 @@
                                          "UNIXPATH", psock_path);
   test = GNUNET_CLIENT_service_test (MSHD_LOCAL, ctx_local.cfg,
                                      GNUNET_TIME_UNIT_SECONDS,
-                                     &result_cb, NULL);
+                                     &status_cb, NULL);
 }
 
 
@@ -641,18 +643,18 @@
  *
  * @param cls NULL
- * @param result GNUNET_YES if the service is running,
+ * @param status GNUNET_YES if the service is running,
  *               GNUNET_NO if the service is not running
  *               GNUNET_SYSERR if the configuration is invalid




reply via email to

[Prev in Thread] Current Thread [Next in Thread]